==> ponyc-0.13.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/random-MT.md <==
# MT

A Mersenne Twister. This is a non-cryptographic random number generator.


```pony
class ref MT is
  Random ref
```

#### Implements

* [Random](random-Random) ref

---

## Constructors

### create

Create with the specified seed. Returned values are deterministic for a
given seed.


```pony
new ref create(
  seed: U64 val = 5489)
: MT ref^
```
#### Parameters

*   seed: [U64](builtin-U64) val = 5489

#### Returns

* [MT](random-MT) ref^

---

## Public Functions

### next

A random integer in [0, 2^64 - 1]


```pony
fun ref next()
: U64 val
```

#### Returns

* [U64](builtin-U64) val

---

### has_next

```pony
fun tag has_next()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### u8

```pony
fun ref u8()
: U8 val
```

#### Returns

* [U8](builtin-U8) val

---

### u16

```pony
fun ref u16()
: U16 val
```

#### Returns

* [U16](builtin-U16) val

---

### u32

```pony
fun ref u32()
: U32 val
```

#### Returns

* [U32](builtin-U32) val

---

### u64

```pony
fun ref u64()
: U64 val
```

#### Returns

* [U64](builtin-U64) val

---

### u128

```pony
fun ref u128()
: U128 val
```

#### Returns

* [U128](builtin-U128) val

---

### int

```pony
fun ref int(
  n: U64 val)
: U64 val
```
#### Parameters

*   n: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### real

```pony
fun ref real()
: F64 val
```

#### Returns

* [F64](builtin-F64) val

---

## Private Functions

### _populate

Repopulates the state array.


```pony
fun ref _populate()
: None val
```

#### Returns

* [None](builtin-None) val

---

### _n

```pony
fun tag _n()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### _m

```pony
fun tag _m()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### _n1

```pony
fun tag _n1()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### _mask

```pony
fun tag _mask(
  x: U64 val,
  y: U64 val)
: U64 val
```
#### Parameters

*   x: [U64](builtin-U64) val
*   y: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### _matrix

```pony
fun tag _matrix(
  x: U64 val)
: U64 val
```
#### Parameters

*   x: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### _mix

```pony
fun tag _mix(
  x: U64 val,
  y: U64 val)
: U64 val
```
#### Parameters

*   x: [U64](builtin-U64) val
*   y: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### _lower

```pony
fun ref _lower(
  i: USize val,
  x: U64 val)
: U64 val ?
```
#### Parameters

*   i: [USize](builtin-USize) val
*   x: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val ?

---

### _upper

```pony
fun ref _upper(
  i: USize val,
  x: U64 val)
: U64 val ?
```
#### Parameters

*   i: [USize](builtin-USize) val
*   x: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val ?

---

### _wrap

```pony
fun ref _wrap()
: U64 val ?
```

#### Returns

* [U64](builtin-U64) val ?

---

==> ponyc-0.18.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/random-MT.md <==
# MT

A Mersenne Twister. This is a non-cryptographic random number generator. This
should only be used for legacy applications that require a Mersenne Twister,
otherwise use Rand.


```pony
class ref MT is
  Random ref
```

#### Implements

* [Random](random-Random) ref

---

## Constructors

### create

Create with the specified seed. Returned values are deterministic for a
given seed.


```pony
new ref create(
  x: U64 val = 5489,
  y: U64 val = 0)
: MT ref^
```
#### Parameters

*   x: [U64](builtin-U64) val = 5489
*   y: [U64](builtin-U64) val = 0

#### Returns

* [MT](random-MT) ref^

---

## Public Functions

### next

A random integer in [0, 2^64 - 1]


```pony
fun ref next()
: U64 val
```

#### Returns

* [U64](builtin-U64) val

---

### has_next

```pony
fun tag has_next()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### u8

```pony
fun ref u8()
: U8 val
```

#### Returns

* [U8](builtin-U8) val

---

### u16

```pony
fun ref u16()
: U16 val
```

#### Returns

* [U16](builtin-U16) val

---

### u32

```pony
fun ref u32()
: U32 val
```

#### Returns

* [U32](builtin-U32) val

---

### u64

```pony
fun ref u64()
: U64 val
```

#### Returns

* [U64](builtin-U64) val

---

### u128

```pony
fun ref u128()
: U128 val
```

#### Returns

* [U128](builtin-U128) val

---

### int

```pony
fun ref int(
  n: U64 val)
: U64 val
```
#### Parameters

*   n: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### real

```pony
fun ref real()
: F64 val
```

#### Returns

* [F64](builtin-F64) val

---

## Private Functions

### _populate

Repopulates the state array.


```pony
fun ref _populate()
: None val
```

#### Returns

* [None](builtin-None) val

---

### _n

```pony
fun tag _n()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### _m

```pony
fun tag _m()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### _n1

```pony
fun tag _n1()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### _mask

```pony
fun tag _mask(
  x: U64 val,
  y: U64 val)
: U64 val
```
#### Parameters

*   x: [U64](builtin-U64) val
*   y: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### _matrix

```pony
fun tag _matrix(
  x: U64 val)
: U64 val
```
#### Parameters

*   x: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### _mix

```pony
fun tag _mix(
  x: U64 val,
  y: U64 val)
: U64 val
```
#### Parameters

*   x: [U64](builtin-U64) val
*   y: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val

---

### _lower

```pony
fun ref _lower(
  i: USize val,
  x: U64 val)
: U64 val ?
```
#### Parameters

*   i: [USize](builtin-USize) val
*   x: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val ?

---

### _upper

```pony
fun ref _upper(
  i: USize val,
  x: U64 val)
: U64 val ?
```
#### Parameters

*   i: [USize](builtin-USize) val
*   x: [U64](builtin-U64) val

#### Returns

* [U64](builtin-U64) val ?

---

### _wrap

```pony
fun ref _wrap()
: U64 val ?
```

#### Returns

* [U64](builtin-U64) val ?

---
